This function uses fread to guess the delimiter of a text file.
Usage
guess_delim(path)
Value
It returns a character string of length 1: the delimiter.
Arguments
path
The path to a text file containing a rectangular data set.
Author
Laurent Berge
See Also
See peek to have a convenient look at the first lines of a text file.
See guess_delim to guess the delimiter of a text data set.
See guess_col_types to guess the column types of a text data set.
See hdd, sub-.hdd and cash-.hdd
for the extraction and manipulation of out of memory data. For importation of
HDD data sets from text files: see txt2hdd.