- path
Character vector that represents the path to the data. Note that
it can be equal to patterns if multiple files with the same name are to be imported
(if so it must be a fixed pattern, NOT a regular expression).
- dirDest
The destination directory, where the new HDD data should be saved.
- chunkMB
Numeric scalar representing the chunk sizes in MB, defaults to 500MB.
The reading of the file is done chunk-wise, and this argument provides the size
of the chunks.
Instead of using this argument, you can alternatively use
the argument rowsPerChunk which decides
the size of chunks in terms of lines.
- rowsPerChunk
Integer scalar or NULL (default). The reading of the file
is done chunk-wise, this argument, if provided, gives the number of rows per chunk.
By default it is NULL and the number of rows is deduced from the argument chunkMB
and the size of the file. If provided, it replaces the argument chunkMB.
- col_names
The column names, by default is uses the ones of the data set.
If the data set lacks column names, you must provide them.
- col_types
The column types, in the readr fashion.
You can use guess_col_types to find them.
- nb_skip
Integer scalar, default is NULL. Number of lines to skip.
- delim
Character scalar representing the delimiter of the columns, or NULL (default).
By default the algorithm tries to find automatically the delimiter.
If the algorithm fails, you must provide the delimiter with this argument.
- preprocessfun
A function that is applied to the data before saving. Default
is missing. Note that if a function is provided, it MUST return a data.frame,
anything other than data.frame is ignored.
- replace
Logical scalar, default is TRUE.
If replace=TRUE, the default, the destination directory is cleaned before running the query.
If replace=FALSE and the destination directory already contains an HDD data set,
an error is thrown.
- encoding
Character scalar containing the encoding of the file to be read.
By default it is "UTF-8" and is passed to the readr
function locale which is used
in read_delim_chunked (the reading function).
A common encoding in Western Europe is
"ISO-8859-1" (simply use "file filename" in a non-Windows console to get the encoding).
Note that this argument is ignored if the argument locale is not NULL.
- verbose
Logical scalar or NULL (default). If TRUE, then the evolution of
the importing process as well as the time to import are reported.
If NULL, it becomes TRUE when the data to import is greater than 5GB or there are
more than one chunk.
- locale
Either NULL (default), either an object created with locale.
This object will be passed to the reading function
read_delim_chunked and handles
how the data is imported.
- ...
Other arguments to be passed to read_delim_chunked,
quote = "" can be interesting sometimes.